<?php
/*
Plugin Name: Chunk URLs in posts in WordPress
Plugin URI: http://www.theblog.ca/shorten-urls
Description: This plugin shortens long URLs in posts so that they won't break your design. It is *very slightly* modified from <a href="http://www.village-idiot.org/archives/2006/06/29/wp-chunk/">a great plugin to shorten URLs in comments</a>. 
Author: whoo / modified by Peter
Version: 2.1p
Author URI: http://www.village-idiot.org/

Changes:

05/07/08 Version 2.1p

	Modified for use with posts and tested with WordPress 2.5. Added one option -- you can automatically link URLs in posts that are not already linked.

08/01/06 Version 2.0

	Major Change-- Updated for usage in WordPress 2.04.
	Minor Change-- Added commenting for folks that want to adjust where a url is truncated.			

07/07/06 Version 1.2
	
	Major Change-- Incorporated my fix for WordPress Bug 2889 into the plugin.

06/29/06: Version 1.0

	Initial release.


*/

// ------------------------
// The one and only setting
// ------------------------

// Change this setting to be true if you want all non-linked URLs in posts to be links
$wp_chunk_clickable = false;

// -------------------------------------------------
// You should not have to modify anything below this
// -------------------------------------------------

function p_make_chunky($ret)
{
	global $wp_chunk_clickable;

	// Make all non-linked URLs into links
	if ($wp_chunk_clickable) { 
		$ret = make_clickable($ret);
	}
	
	// pad it with a space
	$ret = ' ' . $ret;
	$ret = preg_replace("#(^|[\n ])([\w]+?://[\w\#$%&~/.\-;:=,?@\[\]+]*)#is", "$1<a href='$2' rel='nofollow'>$2</a>", $ret);
	$ret = preg_replace("#(^|[\n ])((www|ftp)\.[\w\#$%&~/.\-;:=,?@\[\]+]*)#is", "$1<a href='http://$2' rel='nofollow'>$2</a>", $ret);
	//chunk those long urls
	p_chunk_url($ret);
	$ret = preg_replace("#(\s)([a-z0-9\-_.]+)@([^,< \n\r]+)#i", "$1<a href=\"mailto:$2@$3\">$2@$3</a>", $ret);	
	// Remove our padding..
	$ret = substr($ret, 1);
	return($ret);
}


function p_chunk_url(&$ret)
{
   
   $links = explode('<a', $ret);
   $countlinks = count($links);
   for ($i = 0; $i < $countlinks; $i++)
   {
      $link = $links[$i];
      
      
      $link = (preg_match('#(.*)(href=")#is', $link)) ? '<a' . $link : $link;

      $begin = strpos($link, '>') + 1;
      $end = strpos($link, '<', $begin);
      $length = $end - $begin;
      $urlname = substr($link, $begin, $length);
      
      /**
       * We chunk urls that are longer than 50 characters. Just change
       * '50' to a value that suits your taste. We are not chunking the link
       * text unless if begins with 'http://', 'ftp://', or 'www.'
       */
$chunked = (strlen($urlname) > 50 && preg_match('#^(http://|ftp://|www\.)#is', $urlname)) ? substr_replace($urlname, '.....', 30, -10) : $urlname;
$ret = str_replace('>' . $urlname . '<', '>' . $chunked . '<', $ret); 

   }
} 

add_filter('the_content', 'p_make_chunky');
?>